0.1.2 (2015-09-18)

- Remove universal flag from wheel package
- Improve documentation
- Add -v switch
- Add CONTRIBUTE.md file

0.1.1 (2015-09-18)

- Fix packaging issues

0.1.0 (2015-09-18)

- Beta release
